@@ -1,17 +1,21 @@
 # NOTE: When updating the registration scheme be sure to check with the
 # anonymous registration impementation of events in the registration module.
 import ast
+import csv
 import re
 import os.path
+import time as ttime
 from datetime import datetime, timedelta
 from datetime import date
 from dateutil.rrule import *
 from decimal import Decimal
 
 from django.contrib.auth.models import User
+from django.core.files.storage import default_storage
 from django.core.urlresolvers import reverse
 from django.db import connection
 from django.db import models
+from django.db.models import Q, Max, Count
 from django.db.models.fields import FieldDoesNotExist
 from django.forms.models import modelformset_factory
 from django.template import Context, Template
@@ -35,9 +39,11 @@ from tendenci.apps.discounts.utils import assign_discount
 from tendenci.core.site_settings.utils import get_setting
 from tendenci.core.perms.utils import get_query_filters
 from tendenci.core.imports.utils import extract_from_excel
-from tendenci.core.base.utils import format_datetime_range
+from tendenci.core.base.utils import format_datetime_range, UnicodeWriter
 from tendenci.core.files.models import File
 from tendenci.core.perms.utils import update_perms_and_save
+from tendenci.core.exports.utils import full_model_to_dict
+from tendenci.core.emails.models import Email
 
 
 try:
@@ -1678,3 +1684,239 @@ def create_member_registration(user, event, form):
                                     'pricing': pricing}
                 registrant = Registrant.objects.create(**registrant_attrs)
                 invoice = registration.save_invoice()
+
+
+def process_event_export(start_dt=None, end_dt=None, event_type=None,
+                         identifier=u'', user_id=0):
+    """
+    This exports all events data and registration configuration.
+    This export needs to be able to handle additional columns for each
+    instance of Pricing, Speaker, and Addon.
+    This export does not include registrant data.
+    """
+    event_fields = [
+        'entity',
+        'type',
+        'title',
+        'description',
+        'all_day',
+        'start_dt',
+        'end_dt',
+        'timezone',
+        'private_slug',
+        'password',
+        'on_weekend',
+        'external_url',
+        'image',
+        'tags',
+        'allow_anonymous_view',
+        'allow_user_view',
+        'allow_member_view',
+        'allow_user_edit',
+        'allow_member_edit',
+        'create_dt',
+        'update_dt',
+        'creator',
+        'creator_username',
+        'owner',
+        'owner_username',
+        'status',
+        'status_detail',
+    ]
+    place_fields = [
+        'name',
+        'description',
+        'address',
+        'city',
+        'state',
+        'zip',
+        'country',
+        'url',
+    ]
+    configuration_fields = [
+        'payment_method',
+        'payment_required',
+        'limit',
+        'enabled',
+        'is_guest_price',
+        'use_custom_reg_form',
+        'reg_form',
+        'bind_reg_form_to_conf_only',
+    ]
+    speaker_fields = [
+        'name',
+        'description',
+    ]
+    organizer_fields = [
+        'name',
+        'description',
+    ]
+    pricing_fields = [
+        'title',
+        'quantity',
+        'groups',
+        'price',
+        'reg_form',
+        'start_dt',
+        'end_dt',
+        'allow_anonymous',
+        'allow_user',
+        'allow_member',
+        'status',
+    ]
+
+    events = Event.objects.filter(status=True)
+    if start_dt and end_dt:
+        events = events.filter(start_dt__gte=start_dt, start_dt__lte=end_dt)
+    if event_type:
+        events = events.filter(type=event_type)
+
+    max_speakers = events.annotate(num_speakers=Count('speaker')).aggregate(Max('num_speakers'))['num_speakers__max']
+    max_organizers = events.annotate(num_organizers=Count('organizer')).aggregate(Max('num_organizers'))['num_organizers__max']
+    max_pricings = events.annotate(num_pricings=Count('registration_configuration__regconfpricing')).aggregate(Max('num_pricings'))['num_pricings__max']
+
+    data_row_list = []
+
+    for event in events:
+        data_row = []
+        # event setup
+        event_d = full_model_to_dict(event, fields=event_fields)
+        for field in event_fields:
+            value = None
+            if field == 'entity':
+                if event.entity:
+                    value = event.entity.entity_name
+            elif field == 'type':
+                if event.type:
+                    value = event.type.name
+            elif field in event_d:
+                value = event_d[field]
+            value = unicode(value).replace(os.linesep, ' ').rstrip()
+            data_row.append(value)
+            
+        if event.place:
+            # place setup
+            place_d = full_model_to_dict(event.place)
+            for field in place_fields:
+                value = place_d[field]
+                value = unicode(value).replace(os.linesep, ' ').rstrip()
+                data_row.append(value)
+        
+        if event.registration_configuration:
+            # config setup
+            conf_d = full_model_to_dict(event.registration_configuration)
+            for field in configuration_fields:
+                if field == "payment_method":
+                    value = event.registration_configuration.payment_method.all()
+                    value = value.values_list('human_name', flat=True)
+                else:
+                    value = conf_d[field]
+                value = unicode(value).replace(os.linesep, ' ').rstrip()
+                data_row.append(value)
+        
+        if event.speaker_set.all():
+            # speaker setup
+            for speaker in event.speaker_set.all():
+                speaker_d = full_model_to_dict(speaker)
+                for field in speaker_fields:
+                    value = speaker_d[field]
+                    value = unicode(value).replace(os.linesep, ' ').rstrip()
+                    data_row.append(value)
+        
+        # fill out the rest of the speaker columns
+        if event.speaker_set.all().count() < max_speakers:
+            for i in range(0, max_speakers - event.speaker_set.all().count()):
+                for field in speaker_fields:
+                    data_row.append('')
+                    
+        if event.organizer_set.all():
+            # organizer setup
+            for organizer in event.organizer_set.all():
+                organizer_d = full_model_to_dict(organizer)
+                for field in organizer_fields:
+                    value = organizer_d[field]
+                    value = unicode(value).replace(os.linesep, ' ').rstrip()
+                    data_row.append(value)
+        
+        # fill out the rest of the organizer columns
+        if event.organizer_set.all().count() < max_organizers:
+            for i in range(0, max_organizers - event.organizer_set.all().count()):
+                for field in organizer_fields:
+                    data_row.append('')
+        
+        reg_conf = event.registration_configuration
+        if reg_conf and reg_conf.regconfpricing_set.all():
+            # pricing setup
+            for pricing in reg_conf.regconfpricing_set.all():
+                pricing_d = full_model_to_dict(pricing)
+                for field in pricing_fields:
+                    if field == 'groups':
+                        value = pricing.groups.values_list('name', flat=True)
+                    else:
+                        value = pricing_d[field]
+                    value = unicode(value).replace(os.linesep, ' ').rstrip()
+                    data_row.append(value)
+        
+        # fill out the rest of the pricing columns
+        if reg_conf and reg_conf.regconfpricing_set.all().count() < max_pricings:
+            for i in range(0, max_pricings - reg_conf.regconfpricing_set.all().count()):
+                for field in pricing_fields:
+                    data_row.append('')
+        
+        data_row_list.append(data_row)
+    
+    fields = event_fields + ["place %s" % f for f in place_fields]
+    fields = fields + ["config %s" % f for f in configuration_fields]
+    for i in range(0, max_speakers):
+        fields = fields + ["speaker %s %s" % (i, f) for f in speaker_fields]
+    for i in range(0, max_organizers):
+        fields = fields + ["organizer %s %s" % (i, f) for f in organizer_fields]
+    for i in range(0, max_pricings):
+        fields = fields + ["pricing %s %s" % (i, f) for f in pricing_fields]
+
+    identifier = identifier or int(ttime.time())
+    file_name_temp = 'export/events/%s_temp.csv' % identifier
+
+    with default_storage.open(file_name_temp, 'wb') as csvfile:
+        csv_writer = UnicodeWriter(csvfile, encoding='utf-8')
+        csv_writer.writerow(fields)
+
+        for row in data_row_list:
+            csv_writer.writerow(row)
+
+    # rename the file name
+    file_name = 'export/events/%s.csv' % identifier
+    default_storage.save(file_name, default_storage.open(file_name_temp, 'rb'))
+
+    # delete the temp file
+    default_storage.delete(file_name_temp)
+
+    # notify user that export is ready to download
+    [user] = User.objects.filter(pk=user_id)[:1] or [None]
+    if user and user.email:
+        download_url = reverse('event.export_download', args=[identifier])
+
+        site_url = get_setting('site', 'global', 'siteurl')
+        site_display_name = get_setting('site', 'global', 'sitedisplayname')
+        parms = {
+            'download_url': download_url,
+            'user': user,
+            'site_url': site_url,
+            'site_display_name': site_display_name,
+            'start_dt': start_dt,
+            'end_dt': end_dt,
+            'type': event_type}
+
+        subject = render_to_string(
+            'events/notices/export_ready_subject.html', parms)
+        subject = subject.strip('\n').strip('\r')
+
+        body = render_to_string(
+            'events/notices/export_ready_body.html', parms)
+
+        email = Email(
+            recipient=user.email,
+            subject=subject,
+            body=body)
+        email.send()
+
